Class: Roject::Project

Inherits:
Object
  • Object
show all
Includes:
LoadSaveable
Defined in:
lib/project.rb

Overview

Created: 7 - 10 - 2016

Instance Method Summary collapse

Methods included from LoadSaveable

included

Constructor Details

#initialize(hash = {}) ⇒ Project

Creates a Project with the given data hash

Parameter: hash - the data to be contained in the project



33
34
35
# File 'lib/project.rb', line 33

def initialize hash={}
	@project = hash
end

Instance Method Details

#hashObject

Returns a hash of the data contained in the project

Return: a hash of the data contained in the project



40
41
42
# File 'lib/project.rb', line 40

def hash
	@project
end