Class: Roject::Project
Overview
Created: 7 - 10 - 2016
Instance Method Summary collapse
-
#hash ⇒ Object
Returns a hash of the data contained in the project.
-
#initialize(hash = {}) ⇒ Project
constructor
Creates a Project with the given data hash.
Methods included from LoadSaveable
Constructor Details
#initialize(hash = {}) ⇒ Project
Creates a Project with the given data hash
Parameter: hash - the data to be contained in the project
33 34 35 |
# File 'lib/project.rb', line 33 def initialize hash={} @project = hash end |
Instance Method Details
#hash ⇒ Object
Returns a hash of the data contained in the project
Return: a hash of the data contained in the project
40 41 42 |
# File 'lib/project.rb', line 40 def hash @project end |