Class: Roject::Project

Inherits:
Object
  • Object
show all
Includes:
LoadSaveable
Defined in:
lib/project.rb

Overview

Created: 7 - 10 - 2016

Instance Method Summary collapse

Methods included from LoadSaveable

included

Constructor Details

#initialize(hash = {}) ⇒ Project

Creates a Project with the given data hash

Parameter: hash - the data to be contained in the project



33
34
35
# File 'lib/project.rb', line 33

def initialize hash={}
	@project = hash
end

Instance Method Details

#config(hash) ⇒ Object



37
38
39
# File 'lib/project.rb', line 37

def config hash
	@project = hash
end

#hashObject

Returns a hash of the data contained in the project

Return: a hash of the data contained in the project



44
45
46
# File 'lib/project.rb', line 44

def hash
	@project
end